@@ -47,7 +47,7 @@ class Scenario:
     if self.init:
       self._continue_scenario(j)
     elif self.nis:
-      self._terminate_scenario(j):
+      self._terminate_scenario(j)
     else
       self._init_scenario(j)
 
